# scalenet
A universal pytorch module for implementing multiscale architectures (UNet, spatial pyramid, SpyNet, res-Unet)

## Introduction
See [overview slides](https://docs.google.com/presentation/d/1Gs5kduVHlGPyNn-X7gnDPuQUb3wP1_8sNgalDV4cOJE/edit?usp=sharing) describing ScaleNet + Artificery.
